Crate scion_sdk_observability

Crate scion_sdk_observability 

Observability crate for logging and prometheus metrics.

Re-exports

pub use tracing_subscriber;

Modules

dedup
Event formatter that collapses runs of identical log events.
log_metrics
Metrics for emitted log entries.
metrics
Prometheus metric registry wrapper and HTTP endpoint implementation to expose metrics.
prometheus_json
A Prometheus encoder that outputs metrics in JSON format.

Structs

RandomSpans
Random span generator.
TracingConfig
Configuration for tracing setup.
TracingSetupError
Error returned when tracing setup fails.

Enums

LogFormat
Selects the log line format.
LogOutput
Selects where log lines are written.

Constants

LOG_LEVEL_ENV
Environment variable to define the log level.

Functions

info_trace_layer
Trace layer that logs at info level and uses random span ids.